@@ -159,7 +159,7 @@ class TestUtils(unittest.TestCase):
             structure_factor=False,
             method="centroid",
             verbose=True)
-        bins, histogram = utils.diffractogram(
+        bins, histogram = utils._diffractogram(
             diffraction_pattern, parameters['detector_center_pixel_z'], parameters['detector_center_pixel_y'])
         histogram[histogram < 0.5 * np.median(histogram)] = 0
 
@@ -223,7 +223,7 @@ class TestUtils(unittest.TestCase):
             method="centroid",
             verbose=True)
 
-        bins, histogram = utils.diffractogram(
+        bins, histogram = utils._diffractogram(
             diffraction_pattern, parameters['detector_center_pixel_z'], parameters['detector_center_pixel_y'])
         histogram[histogram < 0.5 * np.median(histogram)] = 0
 
